@@ -7,15 +7,15 @@
 read.wand <- function(file='file name with path'){
                                         # file is the full excel file name
                                         # asssumes that first sheet is "Main" and second sheet is "Flows".
-  x <- as.matrix(read.xlsx(file,sheetName="Main"))
+  x <- as.matrix(read.xls(file,sheet="Main"))
   d1 <- x[1:8,1] #model info
   n <- as.numeric(as.character(d1[3])) #Number of compartments
-  dat.main <- x[9:(n+9),2:6] #isolate the stocks,imports,exports,respirations
+  dat.main <- x[8:(n+9),2:6] #isolate the stocks,imports,exports,respirations
   dat.main[is.na(dat.main)] <- 0 #zero NA
   vn <- dat.main[1:n,1] #vertex names
   dat.main <- apply(dat.main[,2:5],2,as.numeric)
                                         # get flows
-  F <- read.xlsx(file,sheetName="Flows")
+  F <- read.xls(file,sheet="Flows")
   flow.mat <- as.matrix(F[1:(n),2:(n+1)])
   flow.mat[is.na(flow.mat)] <- 0
   flow.mat <- apply(flow.mat,2,as.numeric)
